quantizationtools.QGridLeaf
===========================

.. abjad-lineage:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf

.. autoclass:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.depth
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.graph_order
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.graphviz_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.graphviz_graph
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.parent
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.parentage_ratios
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.preceding_q_event_proxies
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.pretty_rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.prolation
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.prolations
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.q_event_proxies
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.root
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.rtm_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.start_offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.storage_format
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.succeeding_q_event_proxies
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.duration
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.is_divisible
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.name
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.QGridLeaf.QGridLeaf.QGridLeaf.__setstate__
   :noindex:
